print_extensions_footer

Function print_extensions_footer 

pub(crate) fn print_extensions_footer()
Print installed extensions as a footer after root help output. Skips printing when help is for a subcommand (e.g. tempo node --help).