StatefulValidationFn

Type Alias StatefulValidationFn 

pub type StatefulValidationFn<T> = Arc<dyn Fn(TransactionOrigin, &T, &dyn AccountInfoReader) -> Result<(), InvalidPoolTransactionError> + Sync + Send>;
Additional stateful validation function signature.

Receives the transaction origin, a reference to the transaction, and an account state reader. Returns Ok(()) if the transaction passes or Err to reject it.

Aliased Type

pub struct StatefulValidationFn<T> { /* private fields */ }

Layout

Note: Most layout information is completely unstable and may even differ between compilations. The only exception is types with certain repr(...) attributes. Please see the Rust Reference's “Type Layout” chapter for details on type layout guarantees.

Size: 16 bytes